class SedaConfiguration(object):
  def __init__(self):
    self.__max_size = 1000
    self.__block_when_full = True
    self.__concurrent_consumers = 1


  @property
  def max_size(self):
    return self.__max_size

  @max_size.setter
  def max_size(self, value):
    self.set_max_size(value)

  def set_max_size(self, value):
    self.__max_size = value
    return self

  @property
  def block_when_full(self):
    return self.__block_when_full

  @block_when_full.setter
  def block_when_full(self, value):
    self.set_block_when_full(value)

  def set_block_when_full(self, value):
    self.__block_when_full = value
    return self

  @property
  def concurrent_consumers(self):
    return self.__concurrent_consumers

  @concurrent_consumers.setter
  def concurrent_consumers(self, value):
    self.set_concurrent_consumers(value)

  def set_concurrent_consumers(self, value):
    self.__concurrent_consumers = value
    return self



from multiprocessing import JoinableQueue

from eipiphany_core.framework.base.endpoint import Endpoint

from .seda_configuration import SedaConfiguration
from .seda_source import SedaSource


class SedaEndpoint(Endpoint):

  def __init__(self, primary_id, source_configuration = None):
    super().__init__(primary_id)
    self.__default_config = SedaConfiguration()
    self.__source_configuration = source_configuration
    if not self.__source_configuration:
      self.__source_configuration = self.__default_config
    self.__queue = JoinableQueue(maxsize=self.__source_configuration.max_size)
    self.__source = SedaSource(self.__queue, self.__source_configuration)

  def get_prefix(self):
    return 'seda'

  def process(self, exchange, configuration):
    config = configuration
    if not config:
      config = self.__default_config
    self.__queue.put(exchange, config.block_when_full)

  def get_source(self):
    return self.__source